@@ -1,6 +1,7 @@
 from .github import GithubRepo
+from .pagure import PagureRepo
 
-_SERVERS = [GithubRepo]
+_SERVERS = [GithubRepo, PagureRepo]
 
 
 def get_server_from_url(url):
