@@ -10,7 +10,7 @@ def get_remote_for_pr(repo, pr):
             track_remote = remote
     # Create remote if needed
     if not track_remote:
-        track_remote = GitRemote.create(pr.head_username, pr.head_ssh)
+        track_remote = GitRemote.create(pr.head_username, pr.head_git_url)
     return track_remote
 
 
